// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIovgYJKoZIhvcNAQcCoIIorzCCKKsCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg30MIIGcjCCBFqgAwIBAgITMwAAA3uhCj7LZukBwAAA
// SIG // AAADezANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIzMDUxMTE5MDMzMFoX
// SIG // DTI0MDUwODE5MDMzMFowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAJOpuFVvwZX8es6IIHp1wzKi
// SIG // TB6W/bNlhAg2RxyOXmayw41E23NuahOPrFMSjBFVLPL5
// SIG // QfUjA2L/Iif0dtGA5TYvZRsR3mln6tgqZnCD8ECCzUKI
// SIG // dQYFJzO5Y2koNLSLDvSPAiR8xsU/nXfIpThFOiMDfXnr
// SIG // GmbiFfERnf691t2gy2jB/Oawu6sS5Kyqzbghx8pnuHab
// SIG // NAjHxxsxxzjcFL/2uOByCtFQbGeVKnEDTjyuon4sYabJ
// SIG // u8BC6lkmAim6tjN7hc58ZHK9S3+3CeRxVGxxtszbWk8u
// SIG // j/4TNh9wS8Coy824lCLv7GplBDLFN1D8/ADCSwBfQGfg
// SIG // sh02BwIB1Bra+7plEXFzAeycYL4QiMlyEEWmxBMO5YIh
// SIG // JiLIFJBC7s580kO8IYtk+d5yAUPLtSIC2SHj7dyzz4dP
// SIG // CY9VS2H69CvXi4W0KX6pLlkhdHLEQo/Achl9jVxp29i2
// SIG // gR3VMZgkTIS2qYFpdof6f4jrtMXbOH9Xu9+cEAnBEhxd
// SIG // OqIscwIDAQABo4IBgjCCAX4wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFL7FcgNC
// SIG // ZG2sGuJAz92BD/oS98C4MFQGA1UdEQRNMEukSTBHMS0w
// SIG // KwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRp
// SIG // b25zIExpbWl0ZWQxFjAUBgNVBAUTDTQ2NDIyMys1MDEw
// SIG // MzMwHwYDVR0jBBgwFoAUSG5k5VAF04KqFzc3IrVtqMp1
// SIG // ApUwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL3d3dy5t
// SIG // aWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNybDBhBggrBgEFBQcB
// SIG // AQRVMFMwUQYIKwYBBQUHMAKGRWh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNydDAMBgNVHRMBAf8E
// SIG // AjAAMA0GCSqGSIb3DQEBDAUAA4ICAQB+Zbp5xRWoPCFA
// SIG // xpfmeVgVuYxeHBATOkt36f7cQvvyX/dlCOTptS7gJqvW
// SIG // qPyWuZSNq9gwSWrHHF/BnjohTia2lLphcFRNmeXo8THS
// SIG // 8+Fl6FzyjRTc+BWNgdee/MzKYVv8bnAMoRE/Dl5Fdjzl
// SIG // JCtq0I/2zlKLjuBbTb9BsMdlBaLKNzq9wZQGOkXxfcet
// SIG // 0txDHxFfhtKJr6GPIAl7BokhJeTBtsrGicMXlYDACNHf
// SIG // Nz7jHbgDHbuSbf2p29WruXCrIvg29zDrj2CnGJfTWLhY
// SIG // 48GZh1h88OeCkufx4YUba2FSUV+QPoPtYOCrmCFL9lmg
// SIG // vIhds1oAibxMDI/YwLV9//Jd9VILgTvWZfv22PyuXnIM
// SIG // /kNEHVExKj7UBqx3JmHwh/AOeUia1ihWkJEP2/J9JNhn
// SIG // n2A2eu7FFzYhAQYLhQ01FajGdixk7TqVlpA8Ofm1t+Pw
// SIG // cilbnM9ZEbP5y/HN1Lu35SOhDCPx9nyhBcQda0CB0O8k
// SIG // gFq0U/q7FBIGwNG7/gJ535bIaAGS/A6RUMBeHqBqMBQk
// SIG // khrFPx3Vsfq75WrHzCnMsKcA7tG5ZyV5ld6SbJ2ddNUv
// SIG // iajw3lcR5GL6ECdQB8jDqMNE1eJOmQ9kynznLEGbCHRl
// SIG // M7Pu5rf7QXn1h1GWmIYMy5WMcH1323Fh1RaegqARdyQL
// SIG // hdiE5kXk6jCCB3owggVioAMCAQICCmEOkNIAAAAAAAMw
// SIG // DQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
// SIG // ZmljYXRlIEF1dGhvcml0eSAyMDExMB4XDTExMDcwODIw
// SIG // NTkwOVoXDTI2MDcwODIxMDkwOVowfjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUg
// SIG // U2lnbmluZyBQQ0EgMjAxMTCCAiIwDQYJKoZIhvcNAQEB
// SIG // BQADggIPADCCAgoCggIBAKvw+nIQHC6t2G6qghBNNLry
// SIG // tlghn0IbKmvpWlCquAY4GgRJun/DDB7dN2vGEtgL8DjC
// SIG // mQawyDnVARQxQtOJDXlkh36UYCRsr55JnOloXtLfm1Oy
// SIG // CizDr9mpK656Ca/XllnKYBoF6WZ26DJSJhIv56sIUM+z
// SIG // RLdd2MQuA3WraPPLbfM6XKEW9Ea64DhkrG5kNXimoGMP
// SIG // LdNAk/jj3gcN1Vx5pUkp5w2+oBN3vpQ97/vjK1oQH01W
// SIG // KKJ6cuASOrdJXtjt7UORg9l7snuGG9k+sYxd6IlPhBry
// SIG // oS9Z5JA7La4zWMW3Pv4y07MDPbGyr5I4ftKdgCz1TlaR
// SIG // ITUlwzluZH9TupwPrRkjhMv0ugOGjfdf8NBSv4yUh7zA
// SIG // IXQlXxgotswnKDglmDlKNs98sZKuHCOnqWbsYR9q4ShJ
// SIG // nV+I4iVd0yFLPlLEtVc/JAPw0XpbL9Uj43BdD1FGd7P4
// SIG // AOG8rAKCX9vAFbO9G9RVS+c5oQ/pI0m8GLhEfEXkwcNy
// SIG // euBy5yTfv0aZxe/CHFfbg43sTUkwp6uO3+xbn6/83bBm
// SIG // 4sGXgXvt1u1L50kppxMopqd9Z4DmimJ4X7IvhNdXnFy/
// SIG // dygo8e1twyiPLI9AN0/B4YVEicQJTMXUpUMvdJX3bvh4
// SIG // IFgsE11glZo+TzOE2rCIF96eTvSWsLxGoGyY0uDWiIwL
// SIG // AgMBAAGjggHtMIIB6TAQBgkrBgEEAYI3FQEEAwIBADAd
// SIG // BgNVHQ4EFgQUSG5k5VAF04KqFzc3IrVtqMp1ApUwGQYJ
// SIG // KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQD
// SIG // AgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU
// SIG // ci06AjGQQ7kUBU7h6qfHMdEjiTQwWgYDVR0fBFMwUTBP
// SIG // oE2gS4ZJaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0MjAxMV8y
// SIG // MDExXzAzXzIyLmNybDBeBggrBgEFBQcBAQRSMFAwTgYI
// SIG // KwYBBQUHMAKGQmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0MjAxMV8yMDEx
// SIG // XzAzXzIyLmNydDCBnwYDVR0gBIGXMIGUMIGRBgkrBgEE
// SIG // AYI3LgMwgYMwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cu
// SIG // bWljcm9zb2Z0LmNvbS9wa2lvcHMvZG9jcy9wcmltYXJ5
// SIG // Y3BzLmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBwAG8AbABpAGMAeQBfAHMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAZ/KGpZjg
// SIG // VHkaLtPYdGcimwuWEeFjkplCln3SeQyQwWVfLiw++MNy
// SIG // 0W2D/r4/6ArKO79HqaPzadtjvyI1pZddZYSQfYtGUFXY
// SIG // DJJ80hpLHPM8QotS0LD9a+M+By4pm+Y9G6XUtR13lDni
// SIG // 6WTJRD14eiPzE32mkHSDjfTLJgJGKsKKELukqQUMm+1o
// SIG // +mgulaAqPyprWEljHwlpblqYluSD9MCP80Yr3vw70L01
// SIG // 724lruWvJ+3Q3fMOr5kol5hNDj0L8giJ1h/DMhji8MUt
// SIG // zluetEk5CsYKwsatruWy2dsViFFFWDgycScaf7H0J/je
// SIG // LDogaZiyWYlobm+nt3TDQAUGpgEqKD6CPxNNZgvAs031
// SIG // 4Y9/HG8VfUWnduVAKmWjw11SYobDHWM2l4bf2vP48hah
// SIG // mifhzaWX0O5dY0HjWwechz4GdwbRBrF1HxS+YWG18NzG
// SIG // GwS+30HHDiju3mUv7Jf2oVyW2ADWoUa9WfOXpQlLSBCZ
// SIG // gB/QACnFsZulP0V3HjXG0qKin3p6IvpIlR+r+0cjgPWe
// SIG // +L9rt0uX4ut1eBrs6jeZeRhL/9azI2h15q/6/IvrC4Dq
// SIG // aTuv/DDtBEyO3991bWORPdGdVk5Pv4BXIqF4ETIheu9B
// SIG // CrE/+6jMpF3BoYibV3FWTkhFwELJm3ZbCoBIa/15n8G9
// SIG // bW1qyVJzEw16UM0xghoiMIIaHgIBATCBlTB+MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
// SIG // Q29kZSBTaWduaW5nIFBDQSAyMDExAhMzAAADe6EKPstm
// SIG // 6QHAAAAAAAN7MA0GCWCGSAFlAwQCAQUAoIGuMBkGCSqG
// SIG // SIb3DQEJAzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcC
// SIG // AQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEi
// SIG // BCCk0LbOeo0Jl3UzqyYcR3jw0T+iGBzKrXSBXSbuitil
// SIG // gzBCBgorBgEEAYI3AgEMMTQwMqAUgBIATQBpAGMAcgBv
// SIG // AHMAbwBmAHShGoAYaHR0cDovL3d3dy5taWNyb3NvZnQu
// SIG // Y29tMA0GCSqGSIb3DQEBAQUABIIBgDtcjoyKuHNu9hIs
// SIG // Tdwg9y73LBD15WHlVfW77zi/XhSfjsFfk6j4RjQZV7pR
// SIG // mOG2coM7WfztP3TZS8QkaazYmZYs9zypU9yOl+4LaxGz
// SIG // kggp0hHawYOBcAu+/WWzTgFxZvmiee4igvBW4wmMFRt4
// SIG // nYtlNupp5ScQlmsMnPv1I9qDCL0W9yprXLh/oevTxcOE
// SIG // AVKyxZFn+Ld19LlezGFpX6pAX8EVns79vbNdUmEpDXxF
// SIG // LaCXjcEwEof81ND25i/g9BRHpchHFih28wYWADkrwfP4
// SIG // cVi4WPU/MS/dzzbFoeBfyEKpzj5ySOasEZ61PBvKM2b6
// SIG // f0sHIfPaCeYIYVv0pmXTmQchWwJvAWnqIYGGOXOtS3t7
// SIG // WsRBc4ZQ7fJUu8rciIDfya899bmPk2lK8a4PNQs6yu1k
// SIG // A23V9PXNC+xkt/ViHe585+O3QFiU0LOkpNDlT3UuO8FL
// SIG // E4162XAhqedlRJhdVHNFGjAfh+tAowqRDvmPJJCCFrZi
// SIG // rwdWNZhpHmtlvKGCFywwghcoBgorBgEEAYI3AwMBMYIX
// SIG // GDCCFxQGCSqGSIb3DQEHAqCCFwUwghcBAgEDMQ8wDQYJ
// SIG // YIZIAWUDBAIBBQAwggFZBgsqhkiG9w0BCRABBKCCAUgE
// SIG // ggFEMIIBQAIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
// SIG // AwQCAQUABCAYLHeg2MtRToqCzlriiNu+L+ABybJR7PFh
// SIG // n5uhY3gtigIGZN5Cy2rgGBMyMDIzMDgyNTIyNTMxMC4x
// SIG // MTZaMASAAgH0oIHYpIHVMIHSMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMS0wKwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBP
// SIG // cGVyYXRpb25zIExpbWl0ZWQxJjAkBgNVBAsTHVRoYWxl
// SIG // cyBUU1MgRVNOOjJBRDQtNEI5Mi1GQTAxMSUwIwYDVQQD
// SIG // ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIR
// SIG // ezCCBycwggUPoAMCAQICEzMAAAGxypBD7gvwA6sAAQAA
// SIG // AbEwDQYJKoZIhvcNAQELBQAwfDELMAkGA1UEBhMCVVMx
// SIG // EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
// SIG // ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
// SIG // dGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgUENBIDIwMTAwHhcNMjIwOTIwMjAyMTU5WhcNMjMx
// SIG // MjE0MjAyMTU5WjCB0jELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEt
// SIG // MCsGA1UECxMkTWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0
// SIG // aW9ucyBMaW1pdGVkMSYwJAYDVQQLEx1UaGFsZXMgVFNT
// SIG // IEVTTjoyQUQ0LTRCOTItRkEwMTElMCMGA1UEAxMcTWlj
// SIG // cm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCCAiIwDQYJ
// SIG // KoZIhvcNAQEBBQADggIPADCCAgoCggIBAIaiqz7V7BvH
// SIG // 7IOMPEeDM2UwCpM8LxAUPeJ7Uvu9q0RiDBdBgshC/SDr
// SIG // e3/YJBqGpn27a7XWOMviiBUfMNff51NxKFoSX62Gpq36
// SIG // YLRZk2hN1wigrCO656z5pVTjJp3Q8jdYAJX3ruJea3cc
// SIG // fTgxAgT3Uv/sP4w0+yZAYa2JZalV3MBgIFi3VwKFA4Cl
// SIG // Qcr+V4SpGzqz8faqabmYypuJ35Zn8G/201pAN2jDEOu7
// SIG // QaDC0rGyDdwSTVmXcHM46EFV6N2F69nwfj2DZh74gnA1
// SIG // DB7NFcZn+4v1kqQWn7AzBJ+lmOxvKrURlV/u19Mw1YP+
// SIG // zVQyzKn5/4r/vuYSRj/thZr+FmZAUtTAacLzouBENuaS
// SIG // BuOY1k330eMp8nndSNUsUjj/nn7gcdFqzdQNudJb+Xxm
// SIG // Rwi9LwjA0/8PlOsKTZ8Xw6EEWPVLfNojSuWpZMTaMzz/
// SIG // wzSPp5J02kpYmkdl50lwyGRLO5X7iWINKmoXySdQmRdi
// SIG // GMTkvRStXKxIoEm/EJxCaI+k4S3+BWKWC07EV5T3UG7w
// SIG // bFb4LfvgbbaKM58HytAyjDnO9fEi0vrp8JFTtGhdtwhE
// SIG // EkraMtGVt+CvnG0ZlH4mvpPRPuJbqE509e6CqmHwzTuU
// SIG // ZPFMFWvJn4fPv0d32Ws9jv2YYmE/0WR1fULs+TxxpWgn
// SIG // 1z0PAOsxSZRPAgMBAAGjggFJMIIBRTAdBgNVHQ4EFgQU
// SIG // 9Jtnke8NrYSK9fFnoVE0pr0OOZMwHwYDVR0jBBgwFoAU
// SIG // n6cVXQBeYl2D9OXSZacbUzUZ6XIwXwYDVR0fBFgwVjBU
// SIG // oFKgUIZOaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUy
// SIG // MFBDQSUyMDIwMTAoMSkuY3JsMGwGCCsGAQUFBwEBBGAw
// SIG // XjBcBggrBgEFBQcwAoZQaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBU
// SIG // aW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcnQwDAYD
// SIG // VR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcD
// SIG // CDAOBgNVHQ8BAf8EBAMCB4AwDQYJKoZIhvcNAQELBQAD
// SIG // ggIBANjnN5JqpeVShIrQIaAQnNVOv1cDEmCkD6oQufX9
// SIG // NGOX28Jw/gdkGtMJyagA0lVbumwQla5LPhBm5LjIUW/5
// SIG // aYhzSlZ7lxeDykw57wp2AqoMAJm7bXcXtJt/HyaRlN35
// SIG // hAhBV+DmGnBIRcE5C2bSFFY3asD50KUSCPmKl/0NFadP
// SIG // eoNqbj5ZUna8VAfMSDsdxeyxjs8r/9Vpqy8lgIVBqRrX
// SIG // tFt6n1+GFpJ+2AjPspfPO7Y+Y/ozv5dTEYum5eDLDdD1
// SIG // thQmHkW8s0BBDbIOT3d+dWdPETkf50fM/nALkMEdvYo2
// SIG // gyiJrOSG0a9Z2S/6mbJBUrgrkgPp2HjLkycR4Nhwl67e
// SIG // hAhWxJGKD2gRk88T2KKXLiRHAoYTZVpHbgkYLspBLJs9
// SIG // C77ZkuxXuvIOGaId7EJCBOVRMJygtx8FXpoSu3jWEdau
// SIG // 0WBMXxhVAzEHTu7UKW3Dw+KGgW7RRlhrt589SK8lrPSv
// SIG // PM6PPnqEFf6PUsTVO0bOkzKnC3TOgui4JhlWliigtEtg
// SIG // 1SlPMxcdMuc9uYdWSe1/2YWmr9ZrV1RuvpSSKvJLSYDl
// SIG // Of6aJrpnX7YKLMRoyKdzTkcvXw1JZfikJeGJjfRs2cT2
// SIG // JIbiNEGK4i5srQbVCvgCvdYVEVZXVW1Iz/LJLK9XbIkM
// SIG // MjmECJEsa07oadKcO4ed9vY6YYBGMIIHcTCCBVmgAwIB
// SIG // AgITMwAAABXF52ueAptJmQAAAAAAFTANBgkqhkiG9w0B
// SIG // AQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UE
// SIG // AxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0
// SIG // aG9yaXR5IDIwMTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAw
// SIG // OTMwMTgzMjI1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMDCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoC
// SIG // ggIBAOThpkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxO
// SIG // dcjKNVf2AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+
// SIG // uDZnhUYjDLWNE893MsAQGOhgfWpSg0S3po5GawcU88V2
// SIG // 9YZQ3MFEyHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJp
// SIG // rx2rrPY2vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxq
// SIG // D89d9P6OU8/W7IVWTe/dvI2k45GPsjksUZzpcGkNyjYt
// SIG // cI4xyDUoveO0hyTD4MmPfrVUj9z6BVWYbWg7mka97aSu
// SIG // eik3rMvrg0XnRm7KMtXAhjBcTyziYrLNueKNiOSWrAFK
// SIG // u75xqRdbZ2De+JKRHh09/SDPc31BmkZ1zcRfNN0Sidb9
// SIG // pSB9fvzZnkXftnIv231fgLrbqn427DZM9ituqBJR6L8F
// SIG // A6PRc6ZNN3SUHDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XY
// SIG // cz1DTsEzOUyOArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7X
// SIG // KHYC4jMYctenIPDC+hIK12NvDMk2ZItboKaDIV1fMHSR
// SIG // lJTYuVD5C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLb
// SIG // JbqvUAV6bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtF
// SIG // tvUeh17aj54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB
// SIG // 2TASBgkrBgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcV
// SIG // AgQWBBQqp1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4E
// SIG // FgQUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUw
// SIG // UzBRBgwrBgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYz
// SIG // aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9E
// SIG // b2NzL1JlcG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoGCCsG
// SIG // AQUFBwMIMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBB
// SIG // MAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8G
// SIG // A1UdIwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYG
// SIG // A1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9z
// SIG // b2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0Nl
// SIG // ckF1dF8yMDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQRO
// SIG // MEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9z
// SIG // b2Z0LmNvbS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIw
// SIG // MTAtMDYtMjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCd
// SIG // VX38Kq3hLB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOX
// SIG // PTEztTnXwnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7p
// SIG // Zmc6U03dmLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99q
// SIG // b74py27YP0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G
// SIG // 82jfZfakVqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis
// SIG // 9/kpicO8F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbC
// SIG // HcNhcy4sa3tuPywJeBTpkbKpW99Jo3QMvOyRgNI95ko+
// SIG // ZjtPu4b6MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0sHrY
// SIG // UP4KWN1APMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNtyo4J
// SIG // vbMBV0lUZNlz138eW0QBjloZkWsNn6Qo3GcZKCS6OEua
// SIG // bvshVGtqRRFHqfG3rsjoiV5PndLQTHa1V1QJsWkBRH58
// SIG // oWFsc/4Ku+xBZj1p/cvBQUl+fpO+y/g75LcVv7TOPqUx
// SIG // UYS8vwLBgqJ7Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrp
// SIG // NPgkNWcr4A245oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6g
// SIG // MTN9vMvpe784cETRkPHIqzqKOghif9lwY1NNje6CbaUF
// SIG // EMFxBmoQtB1VM1izoXBm8qGCAtcwggJAAgEBMIIBAKGB
// SIG // 2KSB1TCB0jELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UE
// SIG // CxMkTWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBM
// SIG // aW1pdGVkMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjoy
// SIG // QUQ0LTRCOTItRkEwMTElMCMGA1UEAxMcTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsOAwIa
// SIG // AxUA7WSxvqQDbA7vyy69Tn0wP5BGxyuggYMwgYCkfjB8
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNy
// SIG // b3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDANBgkqhkiG
// SIG // 9w0BAQUFAAIFAOiTTF4wIhgPMjAyMzA4MjUyMzUwNTRa
// SIG // GA8yMDIzMDgyNjIzNTA1NFowdzA9BgorBgEEAYRZCgQB
// SIG // MS8wLTAKAgUA6JNMXgIBADAKAgEAAgIl2gIB/zAHAgEA
// SIG // AgIRSTAKAgUA6JSd3gIBADA2BgorBgEEAYRZCgQCMSgw
// SIG // JjAMBgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIB
// SIG // AAIDAYagMA0GCSqGSIb3DQEBBQUAA4GBAKWCHW6BWdjm
// SIG // QSP9awE9o0M4P+OtT52GHp+UCB8imBzpFvg+gPvC+weN
// SIG // cKwYYw0YVOpwA/+64BzZr7ZMdC4pGmDfapFKxiaB/yJv
// SIG // vtE4rxsKNPOurOe66kI0qmCd75vaZbjhah8+ENpdY8Ms
// SIG // 2HDElyCGNK9m9hdLC7crcB24b/IsMYIEDTCCBAkCAQEw
// SIG // gZMwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
// SIG // TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMA
// SIG // AAGxypBD7gvwA6sAAQAAAbEwDQYJYIZIAWUDBAIBBQCg
// SIG // ggFKMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAv
// SIG // BgkqhkiG9w0BCQQxIgQgcXlKzUxgxRlvfjIPy+dg6FHF
// SIG // HOqlBOY/nAJVuy/5haEwgfoGCyqGSIb3DQEJEAIvMYHq
// SIG // MIHnMIHkMIG9BCCD7Q2LFFvfqeDoy9gpu35t6dYerrDO
// SIG // 0cMTlOIomzTPbDCBmDCBgKR+MHwxCzAJBgNVBAYTAlVT
// SIG // MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
// SIG // ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
// SIG // YXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0
// SIG // YW1wIFBDQSAyMDEwAhMzAAABscqQQ+4L8AOrAAEAAAGx
// SIG // MCIEIEpKjPyDnYum3L7HnAGQvolAIcPoxfwuRuC00utK
// SIG // v8cIMA0GCSqGSIb3DQEBCwUABIICAF0ADvRbj65fNJUT
// SIG // szGTh4T42YHyEUEtxiMu7BdGq1WEQpvvseICxR3sSsaP
// SIG // UkgBiPLprzGCSvm0U3ZtRN2rli1z8TLjVgFgair1kbe5
// SIG // 3xhO+vXASryPyl924zCgGH2q80D0bPZ03ahK5jfq0XHQ
// SIG // 6cJ52uz3QFKwgF3v7sYXindy3A/dVEdCPOc6Obdhi6De
// SIG // xcFirUS3pWi7Jk7Rs9Dd6+d/aJtGHgZ+wHmR6qKilpwK
// SIG // /raJVOUPa8Dy6zFysamVKlKza0ti5y6y1IuVVbKQUAij
// SIG // dGXgbpaK6d2d8Pnc7pRg3TsnDCS5reQjNEnkaY/kuFa3
// SIG // IeO129ziPdKReiQK3yTQZ/FAOu2Y3CTqkuFZvfggfvP7
// SIG // Bm05Nvr0t/gVVPKUUNkl3uANQQrNmPLXK3k0ivobqsvw
// SIG // uU40gLqRENE6wPGN1HxTw95Ty2P7t4Z4PqwjGOWXDoHS
// SIG // Zom/UJz9/zncVtfof6OG/v6cdjPF7WaiPgOOC5WTcJq/
// SIG // MKyenNzgPXWo2fRsrrgPRVAtjjcHLbAyLPrvGVHR+PoV
// SIG // VuTvBsb3u5XR/o4XGOpYytuywoMslV4eIptwHCza/H8K
// SIG // U7zJ2kBj1Fb3fQxvWlgJbtFZvVFprNhdKJGWfp877J7Y
// SIG // jlsCwMVbNGjc47O0BXehfznJ2wuozXZqFwWZmNjqdMZg
// SIG // /SYEbP78
// SIG // End signature block
